@@ -4,8 +4,8 @@
 #'  In each block, groups of moose are observed (usually through an aerial survey).
 #'  For each group of moose, the number of moose is recorded along with attributes
 #'  such as sex or age.
-#'  MoosePopR() assumes that sightability is 100%.
-#'  Use the SightabilityPopR() function to adjust for sightability < 100%
+#'  MoosePopR() assumes that sightability is 100\%.
+#'  Use the SightabilityPopR() function to adjust for sightability < 100\%.
 #'
 #' @template survey.data.input
 #' @param conf.level Confidence level used to create confidence intervals.
@@ -50,7 +50,7 @@ MoosePopR <- function(
 
   options.old <- options()
   options(survey.lonely.psu=survey.lonely.psu)  # how to deal with lonely PSU
-  version <- "2020-06-01"
+  version <- "2021-01-01"
 # Error checking
 # Be sure that survey.data, survey.block.area, and stratum.data are data.frames
   if( !is.data.frame(survey.data))      stop("survey.data is not a data frame")
@@ -109,13 +109,15 @@ MoosePopR <- function(
 # check the block area to the survey data
 # make sure no conflict with variable between the two sources except for block.id.var
   common.names <- intersect(names(survey.block.area), names(survey.data))
-  if(length(common.names)>1)stop("Too many common variables in survey.block.area and survey.data: ", paste(common.names, collapse=" "))
-  survey.data <- merge(survey.data, survey.block.area, by=block.id.var, all.x=TRUE)
+  if(length(common.names)>1)warning("Multiple common variables in survey.block.area and survey.data: ", paste(common.names, collapse=", "),
+                                    "; Will merge on the ", block.id.var," variable only.", immediate.=TRUE)
+  survey.data <- merge(survey.data, survey.block.area[,c(block.id.var, block.area.var)], by=block.id.var, all.x=TRUE)
   
 # Merge the stratum information to the survey data
   common.names <- intersect(names(stratum.data), names(survey.data))
-  if(length(common.names)>1)stop("Too many common variables in stratum info and survey data: ", paste(common.names, collapse=" "))
-  survey.data <- merge(survey.data, stratum.data,      by=stratum.var)
+  if(length(common.names)>1)warning("Multiple common variables in stratum info and survey data: ", paste(common.names, collapse=", "),
+                                    "; Will merge on the ", stratum.var," variable only.", immediate.=TRUE)
+  survey.data <- merge(survey.data, stratum.data[,c(stratum.var, stratum.blocks.var, stratum.area.var)],      by=stratum.var)
   
 # Check the density, abundance, numerator, and denominator variables
   Type= NA
@@ -181,8 +183,8 @@ MoosePopR <- function(
                                          Var2.total  =Var2.total)
   })
   # merge in block area and total stratum area values
-  block.totals <- merge(block.totals, survey.block.area, by=block.id.var, all.x=TRUE)
-  block.totals <- merge(block.totals, stratum.data,      by=stratum.var,  all.x=TRUE)
+  block.totals <- merge(block.totals, survey.block.area[,c(block.id.var, block.area.var)],                       by=block.id.var, all.x=TRUE)
+  block.totals <- merge(block.totals, stratum.data     [,c(stratum.var, stratum.blocks.var, stratum.area.var)],  by=stratum.var,  all.x=TRUE)
 
   # now for the analysis depending on the type of analysis
   #browser()
